# semfio-mist

This package stores a list of functions and modules that can be used to interact
with the Mist/Juniper Cloud.

The full list of modules will be documented shortly.

## Usage
This library can be installed using the following pip command:
`pip install semfio-mist`

In order to start using the library in your Python scripts, please import the modules
at the beginning of your scripts as follow:
``` Python
from semfio_mist import api
```
